************************************************************
************************************************************
** master do file for Elite Capture Paper
** PIs: Rema Hanna, Ben Olken
** RAs: Sam Solomon
************************************************************
************************************************************

************************************************************
*** 0. preliminaries ***
************************************************************

clear
clear matrix
clear mata

set more off
set mem 256m
set sortseed 10000
capture log close
cap ssc install mat2txt // convert matrix to text
cap ssc install outreg2

******************************************
* set main directory
******************************************
/*
if "`c(machine_type)'" == "PC (64-bit x86-64)" 				{
global rundir "/bbkinghome/solomon6/Elite_Capture"
}
else if "`c(username)'" == "solomon6" 						{
global rundir "/Users/solomon6/Dropbox (MIT)/EliteCapturePaper"
}
else {
di "CANNOT RECOGNIZE MACHINE"
exit
}
*/

global date "09182019"
global rundir "C:\Users\dap320\Dropbox (CID)\EliteCapturePaper"

******************************************
* set globals
******************************************

global coding 			"$rundir/code-PUBLISH/coding_matching" 
global analysis 		"$rundir/code-PUBLISH/analysis" 
global data 			"$rundir/data-PUBLISH"
global originaldata 	"$data/originaldata"
global codeddata 		"$data/codeddata"
global output 			"$rundir/output-PUBLISH"
global logs 			"$rundir/log-PUBLISH"

** start log
cap erase "$logs/master_log_$date.smcl"
log using "$logs/master_log_$date", replace

************************************************************
*** 1. coding and matching ***
************************************************************

** coding baseline variables
do "$coding/coding baseline.do"

** coding pmt
do "$coding/coding suseti pmt.do"

** coding additional variables for analysis
do "$coding/coding elite relation.do"

** matching baseline survey data and matching results
do "$coding/matching hybrid.do"     

** coding existing social programs
do "$coding/coding existing social programs.do"

** coding miscellaneous variables
do "$coding/coding kitchen-sink variables.do"

** coding for part V of analysis plan
do "$coding/coding_partV_hybrid.do"

************************************************************
*** 2. analysis ***
************************************************************

do "$analysis/0 Table 1AB.do"
do "$analysis/0 Table 1CD.do"
do "$analysis/0 Table 2 Appendix Table 3.do"
do "$analysis/0 Appendix Table 1A.do"
do "$analysis/0 Appendix Table 1B.do"
do "$analysis/0 Appendix Table 2.do"
do "$analysis/0 Appendix Table 4.do"

************************************************************
*** 3. finish! ***
************************************************************

clear

*DONE!!!!!!!!

log close
