************************************************************************************
***Appendix Table 12: Probit Model from Table 7 ************************************
************************************************************************************

clear
clear matrix
clear mata
set more off
set mem 256m
set sortseed 10000

**************************************
*1. Input main data*******************
**************************************

*** Benefits data ***
use "$codeddata/Baseline/historical_getbenefit.dta", clear

*** Other ***
merge 1:1 hhid using "$codeddata/Baseline/matched_baseline_hybrid.dta"
assert _merge==3
drop _merge

*** Elites ***
merge 1:1 hhid using "$codeddata/Baseline/elite_measures.dta"
keep if _merge==3
drop _merge

*** Other ***
merge 1:1 hhid using "$codeddata/Baseline/allvar.dta"
assert _merge==3
drop _merge






**************************************
*2. Coding****************************
**************************************

gen urban=(clas==1)
rename elite_self elite_related_4
rename elite_formal elite_related_5
rename elite_informal elite_related_6
rename elite_self_formal elite_related_7
rename elite_self_informal elite_related_8

local independent "PMTSCORE loghhsize sharekids hhrelated fam_outside relig_participate projects_participation contribute_money hardworking friendly total_savings share_banksavings share_debt ethnic_minority religious_minority hh_eleorless hhwidow disabled death sick income_shock tobacco_alcohol"

replace hhrelated=0 if hhrelated==.
ren getbenefit getbenefit_pkh

**** label variables
label var PMTSCORE "PMT Score"
label var loghhsize "Log household size"
label var sharekids "Share of children in household"
label var hhrelated "Connected with other households"
label var fam_outside "Having family members outside the village"
label var relig_participate "Participating in religious groups"
label var projects_participation "Participating in community projects"
label var contribute_money "Contributing money to village projects"
label var hardworking "Working hard"
label var friendly "Friendliness"
label var total_savings "Total savings amount"
label var share_banksavings "Share of savings in bank"
label var share_debt "Share of debt"
label var ethnic_minority "Being ethnic minority"
label var religious_minority "Being religious minority"
label var hh_eleorless "Household head has elementary education or less"
label var hhwidow "Household head is a widow"
label var disabled "Household head is disabled"
label var death "Household experienced death of family member"
label var sick "Hosuehold has sick family member"
label var income_shock "Household experienced income shock"
label var tobacco_alcohol "Tobacco and/or alcohol consumption"

**************************************
*3. Probit analysis*******************
**************************************

foreach ben in pkh BLT08 askeskin raskin {
*Column 1: PKH
*Column 2: BLT05
*Column 3: BLT08
*Column 4: Jamkesmas
*Column 5: Raskin

forv y = 2/2 { // final paper only includes Formal Elites
local h : word `y' of 1 5 6
local i : word `y' of A B C
*Version A: All elites
*Version B: Formal elites
*Version C: Informal elites

label var elite_related_`h' "Elite"
label var logconsumption "Log per capita consumption"

version 10: probit getbenefit_`ben' elite_related_`h' logconsumption `independent', cl(hhea)
qui summ getbenefit_`ben' if e(sample)
local m0 = r(mean)
if "`ben'"=="pkh" outreg2 using "$output/tables/Appendix Table 2.doc", label word se bdec(3) addstat("Dependent Variable Mean",`m0') ctitle("`ben'") replace
else outreg2 using "$output/tables/Appendix Table 2.doc", label word se bdec(3) addstat("Dependent Variable Mean",`m0') ctitle("`ben'") append
}
}


