************************************************************************************
***Table 7: Social welfare simulations *********************************************
************************************************************************************


clear
clear matrix
clear mata
set more off
set mem 256m
set sortseed 10000

**************************************
*1. Average benefits by program prep**
**************************************

*** Raskin ***
* Price
use "$codeddata/Others/randomization/randomizationresults_111012_modified.dta", clear
drop if maintreatment==2
keep hhea prov
gen price_raskin=2500 if prov=="16"
replace price_raskin=2000 if prov=="18"
replace price_raskin=1800 if prov=="33"
gen price_gap=6600-price_raskin
tempfile price
sa `price', replace

* Quantity
use "$originaldata/Baseline/hh_ksr5.dta", clear
keep if ksr3type=="a"   // rice
replace ksr11_kg=0.824*ksr11_lt if ksr11_kg==. & ksr11_lt!=.  /*density found on: http://www.aqua-calc.com/page/density-table/substance/Rice-coma-and-blank-white-coma-and-blank-medium-grain-coma-and-blank-raw-coma-and-blank-unenriched*/
rename ksr11_kg quantity
replace quantity=0 if ksr08==3
replace quantity=. if ksr08==8
keep hhid quantity
replace quantity=20 if quantity>20 & quantity!=.  // replace the outliers to 100kg. note this used to be 15.
tempfile quantity
sa `quantity', replace


*** PKH ***
* Kids
use "$originaldata/Baseline/hh_ar2",clear
gen count_inprimarysch=0
replace count_inprimarysch=1 if ar19==1 & ar17==2
gen count_inmiddlesch=0
replace count_inmiddlesch=1 if ar19==1 & ar17==3
collapse (sum) count_inprimarysch count_inmiddlesch, by(hhid)
tempfile childeduc
save `childeduc',replace

* More on kids
use "$originaldata/Baseline/hh_kp1",clear
replace kp10=0 if kp10==3
replace kp01=0 if kp01==3
rename kp10 havechild
rename kp01 pregnancy
tempfile hh_kp1
save `hh_kp1',replace





**************************************
*2. Input main data*******************
**************************************

*** Benefits data ***
use "$codeddata/Baseline/historical_getbenefit.dta", clear

*** Other ***
merge 1:1 hhid using "$codeddata/Baseline/matched_baseline_hybrid.dta"
assert _merge==3
drop _merge

*** Elites ***
merge 1:1 hhid using "$codeddata/Baseline/elite_measures.dta"
keep if _merge==3
drop _merge

*** Other ***
merge 1:1 hhid using "$codeddata/Baseline/allvar.dta"
assert _merge==3
drop _merge

*** Raskin tempfiles ***
merge 1:1 hhid using `quantity'
drop if _merge==2
drop _merge
tostring prov, replace
merge m:1 hhea using `price'
assert _merge==3
drop _merge

*** PKH tempfiles ***
merge 1:1 hhid using `childeduc'
keep if _merge==3
drop _merge
merge 1:1 hhid using `hh_kp1'
keep if _merge==3
drop _merge





**************************************
*3. Coding****************************
**************************************

gen urban=(clas==1)
rename elite_self elite_related_4
rename elite_formal elite_related_5
rename elite_informal elite_related_6
rename elite_self_formal elite_related_7
rename elite_self_informal elite_related_8

local independent "PMTSCORE loghhsize sharekids hhrelated fam_outside relig_participate projects_participation contribute_money hardworking friendly total_savings share_banksavings share_debt ethnic_minority religious_minority hh_eleorless hhwidow disabled death sick income_shock tobacco_alcohol"

*restrict sample to non-missings*
replace hhrelated=0 if hhrelated==.

ren getbenefit getbenefit_pkh


**************************************
*4. Benefit amounts*******************
**************************************

*** Raskin ***
gen hh_benefit_raskin=quantity*price_gap
/* Assign mean benefit in that village to all. Benefit is uncorrelated with consumption, so this is fine w.l.o.g. :
. reg hh_benefit_raskin logconsumption if hh_benefit_raskin > 0

      Source |       SS       df       MS              Number of obs =    3150
-------------+------------------------------           F(  1,  3148) =    0.22
       Model |  70301539.4     1  70301539.4           Prob > F      =  0.6401
    Residual |  1.0119e+12  3148   321443705           R-squared     =  0.0001
-------------+------------------------------           Adj R-squared = -0.0002
       Total |  1.0120e+12  3149   321363952           Root MSE      =   17929

------------------------------------------------------------------------------
hh_benefit~n |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
logconsump~n |   -310.934   664.8723    -0.47   0.640    -1614.561    992.6931
       _cons |   41737.42   8671.938     4.81   0.000      24734.2    58740.64
------------------------------------------------------------------------------
*/
bys hhea: egen mean_benefit=mean(hh_benefit)
replace hh_benefit_raskin=mean_benefit
drop mean_benefit
**One other hypothetical
preserve
g hh_benefit_raskin2 = 15*price_gap
assert hh_benefit_raskin2!=.
*** HH utilities with and without benefit ***
gen consumption_got=consumption + hh_benefit_raskin2/hhsize
gen u_got=hhsize*(consumption_got^(-2)/(-2))
gen u_not=hhsize*(consumption^(-2)/(-2))
egen total_rice=total(quantity)
gen slots=total_rice/15
local quota=ceil(slots)
sort logconsumption
gen getbenefit_3=(_n<=`quota')
gen u_3 = u_not if getbenefit_3==0
replace u_3 = u_got if getbenefit_3==1
egen total = total(u_3)
replace total = total*10^8
sum total
local perfect_raskin = `r(mean)'
restore


*** PKH ***
gen hh_benefit_pkh=200000 // baseline
replace hh_benefit_pkh=hh_benefit_pkh+800000 if havechild==1|pregnancy==1
replace hh_benefit_pkh=hh_benefit_pkh+400000 if count_inprimarysch>0 & count_inprimarysch< .
replace hh_benefit_pkh=hh_benefit_pkh+800000 if count_inmiddlesch>0 & count_inmiddlesch<.
replace hh_benefit_pkh=600000 if hh_benefit_pkh<600000
replace hh_benefit_pkh=2200000 if hh_benefit_pkh>2200000
replace hh_benefit_pkh = hh_benefit_pkh/12
	la var hh_benefit_pkh "monthly HH benefit"

*** BLTs ***
gen hh_benefit_BLT05=100000
gen hh_benefit_BLT08=100000

*** Askeskin ***
gen hh_benefit_askeskin=5000


tempfile coded
sa `coded'









*****************************************************************
*5. Utility calculation, looping over benefits*******************
*****************************************************************

* Note: There are 5 scenarios:
* u_0: no program
* u_1: with elite capture
* u_2: without elite capture
* u_3: poorest on PMT
* u_4: poorest on consumption

*****************************************************************
* a. Loop over benefits *****************************************

foreach ben in pkh BLT05 BLT08 askeskin raskin {
u `coded', clear



*****************************************************************
* b. Prepare ****************************************************

*** Drop missings ***
probit getbenefit_`ben' elite_related_1 logconsumption `independent', cl(hhea)
predict p1 // with elite
keep if p1!=.
drop p1
 
*** HH utilities with and without benefit ***
gen consumption_got=consumption + hh_benefit_`ben'/hhsize
gen u_got=hhsize*(consumption_got^(-2)/(-2))
gen u_not=hhsize*(consumption^(-2)/(-2))



*****************************************************************
* c. Loop elites ************************************************

forv y = 1/3 {
local h : word `y' of 1 5 6
local i : word `y' of A B C
*Version 1: All elites
*Version 2: Formal elites
*Version 3: Informal elites
preserve 

*****************************************************************
* d. Scenario 0 *************************************************

gen u_0=hhsize*(consumption^(-2)/(-2))



*****************************************************************
* e. Scenarios 1 and 2 ******************************************

*** Probit model, real world ***
probit getbenefit_`ben' elite_related_`h' logconsumption `independent'
predict p1

*** Hypothetical model without elite relation ***
gen flag_elite_`h'=elite_related_`h'   // generate a flag of being elite related
replace elite_related_`h'=0
predict p2

*** Scale across real and hypothetical model ***
sum p1
local mean_p1=`r(mean)'
sum p2
local mean_p2=`r(mean)'
local ratio=`mean_p1'/`mean_p2'
replace p2=p2*`ratio'  // so that they have the same probability of getting benefit on average

*** Expected utilities under Scenario 1 and Scenario 2 ***
gen u_1 = p1*u_got + (1-p1)*u_not	// elite on
gen u_2 = p2*u_got + (1-p2)*u_not	// elite off



*****************************************************************
* f. Generate quota *********************************************

sum p2
local mean_p3=r(mean)
count 
local sample_size=r(N)
local quota_temp=`mean_p3'*`sample_size'
local quota=round(`quota_temp')



*****************************************************************
* g. Scenario 3 *************************************************

sort PMTSCORE
gen getbenefit_3=(_n<=`quota')
gen u_3 = u_not if getbenefit_3==0
replace u_3 = u_got if getbenefit_3==1




*****************************************************************
* h. Scenario 4 *************************************************

sort logconsumption
gen getbenefit_4=(_n<=`quota')
gen u_4 = u_not if getbenefit_4==0
replace u_4 = u_got if getbenefit_4==1



*****************************************************************
* i. Sums and differences in utilities **************************

*** Sum utilities ***
forv a = 0/4 {
	egen double sum_u`a'=total(u_`a')	// social welfare
	replace sum_u`a'=sum_u`a'*(10^8)	// normalize
	local u`a' = sum_u`a'	// store
	}

*** Differences in utility ***
local temp = `u4' - `u0'     //utility under perfect targeting - utility with no program
forv a = 1/3 {
	local temp`a' = (`u`a'' - `u0')    // scenario - no program
	local temp`a' = `temp`a''/`temp'	// as a percent of possible gain
	}

	
if "`ben'"=="raskin" {
	local tempperf = `perfect_raskin' - `u0'     //utility under perfect targeting - utility with no program//
	forv a = 1/3 {
		local temp`a'2 = (`u`a'' - `u0')    // scenario - no program
		local temp`a'2 = `temp`a'2'/`tempperf'	// as a percent of possible gain
		}
	}


*****************************************************************
* j. Matrix for benefit-panel ***********************************

mat `ben'_`i' = (`u0' \ `u1' \ `u2' \ `u3' \ `u4' \ `temp1' \ `temp2' \ `temp3')
mat list pkh_A 

if "`ben'"=="raskin" mat `ben'_`i'_2 = (`u0' \ `u1' \ `u2' \ `u3' \ `perfect_raskin' \ `temp12' \ `temp22' \ `temp32')

restore
}	// ends elite-type loop
}	// ends benefit loop

**************************************
*6. Combine matrices******************
**************************************

** SMS: added comments below
foreach x in A B {
	mat `x' = (pkh_`x', BLT08_`x', askeskin_`x', raskin_`x')
	mat rownames `x' = WithoutProgram WithEliteOn WithEliteOff PerfectPMT PerfectConsumption ShareWithEliteOn ShareWithEliteOff SharePerfectPMT
	mat colnames `x' = PKH BLT08 Jamkesmas Raskin
	mat raskin2_`x' = (raskin_`x'_2, raskin_`x')
	mat rownames raskin2_`x' = WithoutProgram WithEliteOn WithEliteOff PerfectPMT PerfectConsumption ShareWithEliteOn ShareWithEliteOff SharePerfectPMT
	mat colnames raskin2_`x' = New Original
	if "`x'" == "A" mat2txt, matrix(`x') saving("$output/tables/Appendix Table 3") replace
	if "`x'" == "B" mat2txt, matrix(`x') saving("$output/tables/Table 2") replace
	}





