***************************************
** Coding Elite Connectedness
***************************************

clear
clear matrix
clear mata

set more off
set mem 256m
*set trace on
set sortseed 10000

*****************************************
***They are officers/elites themselves***
*****************************************

u "$originaldata/Baseline/hh_cr00", clear

*recode position variables*
foreach var in cr05a1_jbt cr05a2_jbt cr05a3_jbt cr05a4_jbt cr05a5_jbt cr05b1_jbt cr05b2_jbt cr05b3_jbt cr05b4_jbt cr05b5_jbt cr06_1_jab cr06_2_jab cr06_3_jab cr06_4_jab cr06_5_jab {
	
	*formal
	replace `var' = "1" if `var'=="A"    //Village head//
	replace `var' = "2" if `var'=="B"	 //Head of development, governance, etc//
	replace `var' = "3" if `var'=="C"	 //Head/member of LKMD, LMD, BAPERDES, BP//
	replace `var' = "4" if `var'=="D"	 //RW/Hamlet head//
	replace `var' = "5" if `var'=="E"	 //RT/Dusun head//
	*informal
	replace `var' = "6" if `var'=="F" 	 //Religious leader//
	replace `var' = "7" if `var'=="G"	 //Custom/tribe leader//
	replace `var' = "8" if `var'=="H"	 //Teacher/headmaster//
	replace `var' = "9" if `var'=="I"	 //Other civil servants//
	replace `var' = "10" if `var'=="J"	 //Youth leader//
	replace `var' = "11" if `var'=="K"	 //Posyandu/PKK cader//
	replace `var' = "12" if `var'=="L"	 //Other community leaders//
	replace `var' = "13" if `var'=="V"	 //Others//
	*wrong entry*
	replace `var' = "" if `var'=="Z"
	
	destring `var', replace

}
*generate flags for the mistakingly grouped elite households*
foreach x in a1 a2 a3 a4 a5 {
	
	gen     flag_`x' = .
	replace flag_`x' = 1 if cr05`x'_jbt >=6 & cr05`x'_jbt!=.       //these are wrong: put informal elites into the formal elites column//
	replace flag_`x' = 0 if inrange(cr05`x'_jbt, 1,5)

}
foreach x in b1 b2 b3 b4 b5 {
	
	gen     flag_`x' = .
	replace flag_`x' = 0 if cr05`x'_jbt >=6 & cr05`x'_jbt!=.       
	replace flag_`x' = 1 if inrange(cr05`x'_jbt, 1,5)              //these are wrong: put formal elites into the informal elites column//

}
foreach x in 1 2 3 4 5 {

	gen flag_`x' = .
	replace flag_`x' = 1 if cr06_`x'_jab >=6 & cr06_`x'_jab!=.      //these are wrong: put informal elites into the formal elites column//
	replace flag_`x' = 0 if inrange(cr06_`x'_jab, 1,5)


}

*create a tempfile that contains respondent HHID and the flags*
tempfile cr00_temp
sa `cr00_temp', replace

*drop the respondent household ID*
gen hhea=substr(hhid,1,3)
drop hhid
tempfile cr00
sa `cr00', replace

*create tempfiles that contains mistakingly grouped elite households for later use*
u `cr00_temp', clear
keep hhid flag*
preserve
	keep hhid flag_a1
	rename flag_a1 flag_aa
	keep if flag_aa == 1
	tempfile flag_aa
	sa `flag_aa', replace
restore

preserve
	keep hhid flag_a2
	rename flag_a2 flag_ba
	keep if flag_ba == 1
	tempfile flag_ba
	sa `flag_ba', replace
restore

preserve
	keep hhid flag_a3
	rename flag_a3 flag_ca
	keep if flag_ca == 1
	tempfile flag_ca
	sa `flag_ca', replace
restore

preserve
	keep hhid flag_a4
	rename flag_a4 flag_da
	keep if flag_da == 1
	tempfile flag_da
	sa `flag_da', replace
restore

preserve
	keep hhid flag_a5
	rename flag_a5 flag_ea
	keep if flag_ea == 1
	tempfile flag_ea
	sa `flag_ea', replace
restore

preserve
	keep hhid flag_b1
	rename flag_b1 flag_ab
	keep if flag_ab == 1
	tempfile flag_ab
	sa `flag_ab', replace
restore

preserve
	keep hhid flag_b2
	rename flag_b2 flag_bb
	keep if flag_bb == 1
	tempfile flag_bb
	sa `flag_bb', replace
restore

preserve
	keep hhid flag_b3
	rename flag_b3 flag_cb
	keep if flag_cb == 1
	tempfile flag_cb
	sa `flag_cb', replace
restore

preserve
	keep hhid flag_b4
	rename flag_b4 flag_db
	keep if flag_db == 1
	tempfile flag_db
	sa `flag_db', replace
restore

preserve
	keep hhid flag_b5
	rename flag_b5 flag_eb
	keep if flag_eb == 1
	tempfile flag_eb
	sa `flag_eb', replace
restore

*cr06
preserve
	keep hhid flag_1
	rename flag_1 flag_a
	keep if flag_a == 1
	tempfile flag_a
	sa `flag_a', replace
restore

preserve
	keep hhid flag_2
	rename flag_2 flag_b
	keep if flag_b == 1
	tempfile flag_b
	sa `flag_b', replace
restore

preserve
	keep hhid flag_3
	rename flag_3 flag_c
	keep if flag_c == 1
	tempfile flag_c
	sa `flag_c', replace
restore

preserve
	keep hhid flag_4
	rename flag_4 flag_d
	keep if flag_d == 1
	tempfile flag_d
	sa `flag_d', replace
restore

preserve
	keep hhid flag_5
	rename flag_5 flag_e
	keep if flag_e == 1
	tempfile flag_e
	sa `flag_e', replace
restore


*keep each line separately: these are the formal and informal elites in this RT*
foreach x in a1 a2 a3 a4 a5 b1 b2 b3 b4 b5 {

	u `cr00', clear
	gen hhid=hhea+cr05`x'_hhid if cr05`x'_hhid!=""
	keep if hhid!=""
	
	preserve
		keep if flag_`x' == 0       //these are correct//
		keep hhid
		tempfile 05`x'_nonflag
		sa `05`x'_nonflag', replace
	restore
	
	keep if flag_`x' == 1           //these are wrong, and should be put in the other group//
	keep hhid
	tempfile 05`x'_flag
	sa `05`x'_flag', replace

}


**************************************************
***Append them together to get a list of elites***
**************************************************

*formal elites in this village*
use `05a1_nonflag', clear
append using `05a2_nonflag'
append using `05a3_nonflag'
append using `05a4_nonflag'
append using `05a5_nonflag'
append using `05b1_flag'
append using `05b2_flag'
append using `05b3_flag'
append using `05b4_flag'
append using `05b5_flag'

bys hhid: gen count = _N                //how many votes does each household get?//

preserve
	keep if count>=2
	drop count 
	duplicates drop hhid, force

	tempfile formal_self
	sa `formal_self', replace

	gen elite_self_formal=1
	sa "$codeddata/Baseline/elite_self_formal.dta", replace
restore

keep if count>=4
drop count
duplicates drop hhid, force

tempfile formal_self_4
sa `formal_self_4', replace

***informal elites***
use `05b1_nonflag', clear
append using `05b2_nonflag'
append using `05b3_nonflag'
append using `05b4_nonflag'
append using `05b5_nonflag'
append using `05a1_flag'
append using `05a2_flag'
append using `05a3_flag'
append using `05a4_flag'
append using `05a5_flag'

bys hhid: gen count = _N                //how many votes does each household get?//

preserve
	keep if count>=2
	drop count 
	duplicates drop hhid, force

	tempfile informal_self
	sa `informal_self', replace

	gen elite_self_informal=1
	sa "$codeddata/Baseline/elite_self_informal.dta", replace
restore

keep if count>=4
drop count
duplicates drop hhid, force

tempfile informal_self_4
sa `informal_self_4', replace

***merge together to get a list of elites (2 votes)***
use `informal_self', clear
merge 1:1 hhid using `formal_self'
drop _merge
tempfile elite_self
sa `elite_self', replace

gen elite_self=1
sa "$codeddata/Baseline/elite_self.dta", replace

***merge together to get a list of elites (4 votes)***
use `formal_self_4', clear
merge 1:1 hhid using `informal_self_4'
drop _merge
tempfile elite_self_4
sa `elite_self_4', replace


*****************************************
***They are related to officers/elites***
*****************************************
***We define a HH to be related to officers/elites if they have two/four votes from others***

***CR05:***
local i=1
local j=101
*for each of the 10 forms in CR05, count how many times each household is named*
foreach x in aa ba ca da ea ab bb cb db eb {

use "$originaldata/Baseline/hh_cr05`x'.dta", clear

*take out the flagged ones*
merge m:1 hhid using `flag_`x''
preserve
	if "`x'" != "eb" {    /*no observation in eb + flag*/
	keep if _merge==3
	drop _merge
	*related to the mistakingly grouped ones: who got named? How many times?*
	gen hhea=substr(hhid,1,3)
	drop hhid
	gen hhid=hhea+cr05`x'_hhid if cr05`x'_hhid!=""
	bys hhid: gen num`j'=_N
	keep hhid num`j'
	duplicates drop hhid, force
	tempfile wrong_`x'
	sa `wrong_`x'', replace
	}
restore
keep if _merge==1
drop _merge

*related to the correctly grouped ones: who got named? How many times?*
gen hhea=substr(hhid,1,3)
drop hhid
gen hhid=hhea+cr05`x'_hhid if cr05`x'_hhid!=""
bys hhid: gen num`i'=_N
keep hhid num`i'
duplicates drop hhid, force

tempfile 05`x'
sa `05`x'', replace

local i=`i'+1
local j=`j'+1

}

***CR06:***
local i=11
local j=111
foreach y in a b c d e {
use "$originaldata/Baseline/hh_cr06`y'.dta", clear

*take out the flagged ones*
merge m:1 hhid using `flag_`y''
preserve
	keep if _merge==3
	drop _merge
	*related to the mistakingly grouped ones: who got named? How many times?*
	gen hhea=substr(hhid,1,3)
	drop hhid
	gen hhid=hhea+cr06`y'_hhid if cr06`y'_hhid!=""
	bys hhid: gen num`j'=_N
	cap keep hhid num`j'
	duplicates drop hhid, force
	tempfile wrong_`y'
	sa `wrong_`y'', replace
restore
keep if _merge==1
drop _merge

*related to the correctly grouped ones: who got named? How many times?*
gen hhea=substr(hhid,1,3)
drop hhid
gen hhid=hhea+cr06`y'_hhid if cr06`y'_hhid!=""
keep hhid
bys hhid: gen num`i'=_N
duplicates drop hhid, force

tempfile 06`y'
sa `06`y'', replace

local i=`i'+1
local j=`j'+1

}

*******************************************************************************************
***Merge all the identified elite-related HHs together, get a list of elite-related hhid***
*******************************************************************************************
***related to formal elites***
use `05aa', clear
merge 1:1 hhid using `05ba'
drop _merge
merge 1:1 hhid using `05ca'
drop _merge
merge 1:1 hhid using `05da'
drop _merge
merge 1:1 hhid using `05ea'
drop _merge
merge 1:1 hhid using `06a'
drop _merge
merge 1:1 hhid using `06b'
drop _merge
merge 1:1 hhid using `06c'
drop _merge
merge 1:1 hhid using `06d'
drop _merge
merge 1:1 hhid using `06e'
drop _merge
merge 1:1 hhid using `wrong_ab'
drop _merge
merge 1:1 hhid using `wrong_bb'
drop _merge
merge 1:1 hhid using `wrong_cb'
drop _merge
merge 1:1 hhid using `wrong_db'
drop _merge

drop if hhid==""
egen votes=rowtotal(num1-num5 num11-num15 num106-num109)
drop num*

keep if votes>=2
tempfile formal_related_2
sa `formal_related_2', replace

keep if vote>=4
tempfile formal_related_4
sa `formal_related_4', replace

***related to informal elites***
u `05ab'
merge 1:1 hhid using `05bb'
drop _merge
merge 1:1 hhid using `05cb'
drop _merge
merge 1:1 hhid using `05db'
drop _merge
merge 1:1 hhid using `05eb'
drop _merge
merge 1:1 hhid using `wrong_aa'
drop _merge
merge 1:1 hhid using `wrong_ba'
drop _merge
merge 1:1 hhid using `wrong_ca'
drop _merge
merge 1:1 hhid using `wrong_da'
drop _merge
merge 1:1 hhid using `wrong_ea'
drop _merge
merge 1:1 hhid using `wrong_a'
drop _merge
merge 1:1 hhid using `wrong_b'
drop _merge
merge 1:1 hhid using `wrong_c'
drop _merge
merge 1:1 hhid using `wrong_d'
drop _merge
merge 1:1 hhid using `wrong_e'
drop _merge

drop if hhid==""
egen votes=rowtotal(num6-num10 num101-num105 num111-num115)
drop num*

keep if votes>=2
tempfile informal_related_2
sa `informal_related_2', replace

keep if vote>=4
tempfile informal_related_4
sa `informal_related_4', replace


**************************************
***Merge with the HHs with an elite***
**************************************
***two votes***
u `elite_self', clear
merge 1:1 hhid using `formal_related_2'
drop _merge
merge 1:1 hhid using `informal_related_2'
drop _merge votes
gen elite_related=1

sa "$codeddata/Baseline/elite_related.dta", replace

use `formal_related_2', clear
merge 1:1 hhid using `formal_self'
drop _merge votes
drop if hhid==""
gen elite_formal=1
sa "$codeddata/Baseline/elite_formal.dta", replace

use `informal_related_2', clear
merge 1:1 hhid using `informal_self'
drop _merge votes
drop if hhid==""
gen elite_informal=1
sa "$codeddata/Baseline/elite_informal.dta", replace

***four votes:***
u `elite_self_4', clear
merge 1:1 hhid using `formal_related_4'
drop _merge 
merge 1:1 hhid using `informal_related_4'
drop _merge votes
gen elite_related_2=1

sa "$codeddata/Baseline/elite_related_fourvotes.dta", replace


*****************************************
****Combine different measure together***
*****************************************

merge 1:1 hhid using "$codeddata/Baseline/elite_related.dta"   /*2 votes: elite_related_1*/
drop _merge
rename elite_related elite_related_1

merge 1:1 hhid using "$codeddata/Baseline/elite_self.dta"   /*elite self: elite_related_4*/
drop _merge
merge 1:1 hhid using "$codeddata/Baseline/elite_formal.dta" /*formal elite: elite_related_5*/
drop _merge
merge 1:1 hhid using "$codeddata/Baseline/elite_informal.dta" /*formal elite: elite_related_6*/
drop _merge
merge 1:1 hhid using "$codeddata/Baseline/elite_self_formal.dta" /*formal elite self: elite_related_7*/
drop _merge
merge 1:1 hhid using "$codeddata/Baseline/elite_self_informal.dta" /*formal elite self: elite_related_8*/
drop _merge

merge 1:1 hhid using "$codeddata/Baseline/consumption.dta", keepusing(hhid)
drop if _merge==1   /*only keep those in baseline*/
drop _merge

replace elite_related_1=0 if elite_related_1==.
replace elite_related_2=0 if elite_related_2==.
replace elite_self=0 if elite_self==.
replace elite_formal=0 if elite_formal==.
replace elite_informal=0 if elite_informal==.
replace elite_self_formal=0 if elite_self_formal==.
replace elite_self_informal=0 if elite_self_informal==.

sa "$codeddata/Baseline/elite_measures.dta", replace

