***************************************
** coding kitchen-sink variables
***************************************

clear
clear matrix 
clear mata
set more off
set mem 256m

***Log per capita consumption and Log HH size***
use "$codeddata/Baseline/consumption.dta", clear
keep hhea hhid hhconsumption logconsumption hhsize loghhsize rank_pcexp nhhrank_pcexp rankconsumption
tempfile consumption
sa `consumption', replace

***Disability***
use "$originaldata/Baseline/hh_ar2.dta", clear
gen disabled=0
replace disabled=1 if ar05!="W"
sort hhid
collapse (max) disabled, by(hhid)
la var disabled "binary; 1 if disabled"
tempfile disability
sa `disability', replace

***Number of kids of age<14***
use "$originaldata/Baseline/hh_ar2.dta", clear
gen age14 = (inrange(ar04a_yr,0,14))
collapse (sum) age14, by(hhid)
la var age14 "binary; 1 if age between 0 and 14"
tempfile age14
sa `age14', replace

***HH head with primary education or less; HH head is widow***
use "$originaldata/Baseline/hh_ar2.dta", clear
keep if ar02==1  /*only keep HH heads*/
gen hhwidow=ar06
recode hhwidow(1 2 3 5=0) (4=1)
label var hhwidow "binary; 1 if household head is widow"
rename ar17 educationhhhead
gen hh_eleorless=(educationhhhead==0 | educationhhhead==1 | educationhhhead==2)
tempfile hhhead_edu_widow
sa `hhhead_edu_widow', replace

***Savings***
use "$originaldata/Baseline/hh_sv.dta", clear
bys hhid: egen total_savings=sum(sv01)
gen temp=sv01 if svtype=="a"
bys hhid: egen bank_savings=max(temp)
drop temp
replace bank_savings=0 if bank_savings==.
replace total_savings = total_savings/1000000  /*Changed the denominator from 1,000 to 1,000,000*/
la var total_savings "total savings, in million"
replace bank_savings = bank_savings/1000000  /*Changed the denominator from 1,000 to 1,000,000*/
la var bank_savings "bank savings, in million"
gen share_banksavings=bank_savings/total_savings
la var share_banksavings "share of savings that is in the bank"
//if savings exist in other form than bank account, set share_banksavings to 0
replace share_banksavings=0 if share_banksavings==.
keep hhid total_savings share_banksavings
duplicates drop hhid, force
tempfile savings
sa `savings', replace

***Debt***
use "$originaldata/Baseline/hh_bh.dta", clear
rename bh04 loan
la var loan "household debt"
replace loan=0 if loan==.
keep hhid loan
tempfile loan
sa `loan', replace

***Total connectedness***
use "$originaldata/Baseline/hh_cr01.dta", clear
gen hhea = substr(hhid,1,3)
bys hhid:gen hhrelated =_N
label var hhrelated "Number of households in RT you are related to"
keep hhid hhrelated
gen connected=(hhrelated!=0)
la var connected "binary; 1 if related to some households in the RT"
duplicates drop hhid, force
tempfile connected
sa `connected', replace

***Family members outside village***
use "$originaldata/Baseline/hh_tf1.dta", clear
gen fam_outside = tf02num
replace fam_outside=0 if tf01==3 //tf01 is dummy for having family outside village
label var fam_outside "Number of family members outside the village"
keep hhid fam_outside
tempfile fam_out
sa `fam_out', replace

***tobacco and alcohol consumption
use "$originaldata/Baseline/hh_ks1.dta", clear

foreach var of varlist  ks01_14a ks01_14b ks01_13c{
	replace `var'=. if `var'>=99999990
}

gen tobacco_alcohol = ((ks01_14a + ks01_14b + ks01_13c)*30/7)/1000000 /*normalize by a million*/
la var tobacco_alcohol "monthly consumption of tobacco/alcohol, in million Rp "
replace tobacco_alcohol=0 if tobacco_alcohol==.
tempfile tobacco_alcohol
sa `tobacco_alcohol', replace

***Community participation***
use "$originaldata/Baseline/hh_pm1.dta", clear
gen relig_participate = (pm01b==1)
label var relig_participate "dummy for participation in religious groups" 
gen projects_participation=(pm08x==1)
label var projects_participation "participated in community activities"
gen contribute_money=(pm10==1)
label var contribute_money "contributed money to community activities"
keep hhid relig_participate projects_participation contribute_money
tempfile community
sa `community', replace

***Hardworking***
use "$originaldata/Baseline/hh_pm5a.dta", clear
gen hhea=substr(hhid,1,3)
drop hhid
gen hhid=hhea+pm15a_hhid
bys hhid: egen hardworking=mean(pm15a_line)
la var hardworking "1=least hardworking"
keep hhid hardworking
duplicates drop hhid, force
tempfile hardworking
sa `hardworking', replace

***Friendliness***
use "$originaldata/Baseline/hh_pm6a.dta", clear
gen hhea=substr(hhid,1,3)
drop hhid
gen hhid=hhea+pm16a_hhid
bys hhid: egen friendly=mean(pm16a_line)
la var friendly "1=least friendly"
keep hhid friendly
duplicates drop hhid, force
tempfile friendly
sa `friendly', replace

***shocks***
use "$originaldata/Baseline/hh_ge.dta", clear
gen death_temp= ((getype=="a"&ge01==1)| (getype=="b"&ge01==1))
gen sick_temp= ((getype=="c"&ge01==1)| (getype=="d"&ge01==1))
gen income_shock_temp=((getype=="e"&ge01==1)| (getype=="f"&ge01==1)| (getype=="g"&ge01==1)| (getype=="h"&ge01==1)| (getype=="v"&ge01==1))
bys hhid: egen death=max(death_temp)
la var death "binary; 1 if a family member died"
bys hhid: egen sick=max(sick_temp)
la var sick "binary; 1 if a family member was sick"
bys hhid: egen income_shock=max(income_shock_temp)
la var income_shock "binary; 1 if family experienced income shock"
duplicates drop hhid, force
keep hhid death sick income_shock
tempfile shocks
sa `shocks', replace


***Minority***
use "$originaldata/Baseline/k_data.dta", clear
rename ea hhea
drop if id01==.
duplicates drop hhea, force
keep hhea id03* 
reshape long id03_, i(hhea)
bys hhea: egen temp1=max(id03_)
gen temp2=_j if id03_==temp1
bys hhea: egen ethnicmajority=max(temp2)
keep hhea ethnicmajority
duplicates drop hhea, force
*reconcile the differneces between RT head questionnaires and baseline questionnares*
replace ethnicmajority=ethnicmajority+1 if ethnicmajority>=14&ethnicmajority!=95
tempfile ethnic_maj
sa `ethnic_maj', replace

use "$originaldata/Baseline/k_data.dta", clear
rename ea hhea
drop if id01==.
duplicates drop hhea, force
keep hhea id04*
reshape long id04_, i(hhea)
bys hhea: egen temp1=max(id04_)
gen temp2=_j if id04_==temp1
bys hhea: egen religiousmajority=max(temp2)
keep hhea religiousmajority
duplicates drop hhea, force
*reconcile the differneces between RT head questionnaires and baseline questionnares*
recode religiousmajority (2=3) (3=2) (4=5) (5=4)
tempfile religious_maj
sa `religious_maj', replace

use "$originaldata/Baseline/hh_krt.dta", clear
keep hhid krt02 krt04
gen hhea=substr(hhid,1,3)
merge m:1 hhea using `ethnic_maj'
assert _merge==3
drop _merge
merge m:1 hhea using `religious_maj'
assert _merge==3
drop _merge
gen ethnic_minority=(krt02!=ethnicmajority)
la var ethnic_minority "binary; 1 if household head is ethnic minority"
gen religious_minority=(krt04!=religiousmajority)
la var religious_minority "binary; 1 if household head is religious minority"
keep hhid  ethnic_minority  religious_minority
tempfile minority
sa `minority',replace

use "$codeddata/Baseline/elite_measures.dta", replace
keep elite_related_1 hhid
tempfile elite_conn
sa `elite_conn', replace

******************************
***Merge data sets together***
******************************
use "$codeddata/Baseline/matched_baseline_hybrid.dta", replace
keep hhid hhea kecagroup showup getbenefit hybrid tokohsubtreatment

merge 1:1 hhid using `consumption'
drop if _merge==2
drop _merge
merge 1:1 hhid using `disability'
drop if _merge==2
drop _merge
merge 1:1 hhid using `age14'
drop if _merge==2
drop _merge
merge 1:1 hhid using `hhhead_edu_widow'
drop if _merge==2
drop _merge
merge 1:1 hhid using `savings'
drop if _merge==2
drop _merge
merge 1:1 hhid using `loan'
drop if _merge==2
drop _merge
merge 1:1 hhid using `connected'
drop if _merge==2
drop _merge
merge 1:1 hhid using `fam_out'
drop if _merge==2
drop _merge
merge 1:1 hhid using `tobacco_alcohol'
drop if _merge==2
drop _merge
merge 1:1 hhid using `community'
drop if _merge==2
drop _merge
merge 1:1 hhid using `hardworking'
drop if _merge==2
drop _merge
merge 1:1 hhid using `friendly'
drop if _merge==2
drop _merge
merge 1:1 hhid using `shocks'
drop if _merge==2
drop _merge
merge 1:1 hhid using `minority'
drop if _merge==2
drop _merge
merge 1:1 hhid using `elite_conn'
drop if _merge==2
drop _merge


***sharekids and share_debt***
gen sharekids=age14/hhsize
la var sharekids "share of children under 14 per household"
gen share_debt = loan / hhconsumption
la var share_debt "share of loan in household monthly consumption"

replace connected=0 if connected==.
replace hhrelated=0 if hhrelated==.

** save final data set
save "$codeddata/Baseline/allvar.dta", replace



